/**
 ******************************************************************************
 * @file    mx.c
 * @author  STMicroelectronics - AIS - MCD Team
 * @version 1.0.0
 * @date    Apr 9, 2021
 *
 * @brief Project peripherals configuration files.
 *
 * This files defines the peripherals configuration parameters that can be used
 * in the Low Level API of an eLooM driver - IDrvInit(). It creates a link
 * between the initialization code generated by CubeMX (see the .ioc file
 * in the tools folder) and the eLooM framework.
 *
  ******************************************************************************
  * @attention
  *
  * Copyright (c) 2021 STMicroelectronics
  * All rights reserved.
  *
  * This software is licensed under terms that can be found in the LICENSE file
  * in the root directory of this software component.
  * If no LICENSE file comes with this software, it is provided AS-IS.
  ******************************************************************************
 */

#include "mx.h"
#include "usart.h"
#include "tim.h"
#include "gpio.h"


/**
 * TIM5 initialization parameters.
 */
const MX_TIMParams_t MX_TIM5InitParams = {
    .p_mx_init_f = MX_TIM5_Init,
    .p_tim = &htim5,
    .irq_n = TIM5_IRQn
};

/**
 * TIM16 initialization parameters.
 */
const MX_TIMParams_t MX_TIM16InitParams = {
    .p_mx_init_f = MX_TIM16_Init,
    .p_tim = &htim16,
    .irq_n = TIM1_UP_TIM16_IRQn
};

/**
 * PE0 Initialization parameters.
 */
const MX_GPIOParams_t MX_GPIO_PE0InitParams = {
    MX_GPIO_PE0_Init,
    USER_BUTTON_EXTI_IRQn,
    GPIO_PIN_0,
    GPIOE
};
